pub struct BracketParser { /* private fields */ }Expand description
A parser that can analyze text to determine if positions are inside or outside brackets.
Implementations
Sourceimpl BracketParser
impl BracketParser
Sourcepub fn new() -> Result<Self, String>
pub fn new() -> Result<Self, String>
Creates a new BracketParser instance.
Returns
A Result containing the new BracketParser or an error if the parser could not be initialized.
Sourcepub fn get_final_state(&mut self, code: &str) -> BracketState
pub fn get_final_state(&mut self, code: &str) -> BracketState
Sourcepub fn get_state_at_position(
&self,
byte_position: usize,
tree: &Tree,
) -> BracketState
pub fn get_state_at_position( &self, byte_position: usize, tree: &Tree, ) -> BracketState
Sourcepub fn get_all_states(&mut self, code: &str) -> Vec<BracketState>
pub fn get_all_states(&mut self, code: &str) -> Vec<BracketState>